import pandas as pd
import sys
from read_utils import*

def main():
    #Argument parsing:
    if len(sys.argv) < 2:
        print("Usae: python script.py <root rundir>")
        sys.exit(1)

    root_folder = sys.argv[1]
    from_ts = 3
    to_ts = -1
    aggregate=True

    #Get SDPD per rundir:
    rundirs = find_rundir_folders(root_folder)
    sdpd_list = []
    nodes_list = []
    mpi_per_node_list = []
    omp_per_node_list = []

    for rundir in rundirs:
#        print(f"Found rundir at {rundir}")
        sdpd = get_sdpd_from_rundir(rundir, from_ts, to_ts)
        nodes, mpi, omp = get_hardware_setup(rundir)
#        print(f"NODES:{nodes} MPI: {mpi}, OMP: {omp} SDPD: {sdpd}")
        sdpd_list.append(sdpd)
        nodes_list.append(nodes)
        mpi_per_node_list.append(mpi)
        omp_per_node_list.append(omp)

    df = pd.DataFrame({
        "rundir": rundirs,
        "SDPD": sdpd_list,
        "NODES" : nodes_list,
        "MPI" : mpi_per_node_list,
        "OMP" : omp_per_node_list
        }
    )

    df.sort_values('NODES',inplace=True)
    print(df)
    df.to_csv("output.csv", index=False)

    if aggregate:
        print("Apply agg to SDPD for same NODES, MPI & OMP")
        df_agg = df.groupby(['NODES', 'OMP','MPI']).agg({'SDPD':['mean', 'max', 'min']}).reset_index()
        print(df_agg)
        df_agg.to_csv("output_agg.csv", index=False)



if __name__ == "__main__":
    main()
