import os
import re

def find_rundirs_folders(root_path):
    rundir_folders = []

    for dirpath, _, filenames in os.walk(root_path):
        if "time.step" in filenames:
            rundir_folders.append(dirpath)

    return rundir_folders

def get_timesteps(rundir):
    try:
        with open(os.path.join(rundir, 'time.step')) as file:
            lines = file.readlines()
            if lines: return lines[-1].strip()
            else: return None
    except Exception as e:
        print(e)
        return None

def get_execution_time(rundir):
    try:
        with open(os.path.join(rundir, 'timing.output')) as file:
            b_found=False
            for line in file.readlines():
                if "Elapsed Time (s)  CPU Time (s)" in line:
                    b_found=True
                elif b_found:
                    elap_time, cpu_time = line.strip().split()
                    return elap_time, cpu_time
            return None, None
    except Exception as e:
        print(e)
        return None, None

def get_timestep_timings(rundir, total_ts):
    ts_time_dict = {}
    pattern = re.compile(r'timing step\s+(\d+)\s+:\s+([\d\.]+)')
    try:
        with open(os.path.join(rundir, 'timing.output')) as file:

            for line in file.readlines():
                match = pattern.search(line)
                if match:
                    step = int(match.group(1))
                    time = float(match.group(2))
                    ts_time_dict[step] = time

    except Exception as e:
        print(e)
        return None


    return ts_time_dict


def get_profiling_data(rundir, statistic=None):
    with open(os.path.join(rundir, 'timing.output'), mode="r") as timeFile:
        b=False
        ret = {}
        for line in timeFile.readlines():

            if "Averaged inclusive timing on all processors :" in line:
            #if "Averaged timing on all processors :" in line:

                #print("FOUND AVG TIMING INFO")
                b=True

            if b and len(line.split()) >= 11:
                #print("Found headers")
                continue

            if b and len(line.split()) >= 10:
                columns=line.split()
                section = columns[0]
                elap_time = float(columns[1]) # in seconds
                elap_time_percent = float(columns[2])
                cpu_elap_ratio = float(columns[5])
                aux =(elap_time, elap_time_percent, cpu_elap_ratio)
                if statistic is None:
                    ret[section] = aux
                elif statistic == "elap_time":
                    ret[section] = elap_time  
                elif statistic == "elap_time_perc":
                    ret[section] = elap_time_percent
                else:
                    raise Exception("INVALID STATISTIC!")
            if line == " \n" and b:
                break
    return ret
