#!/bin/bash

#INPUTS:
EORCA_INPUTS="inputs/inputs-eorca1-5y/exp-eorca1-ref/"

#BINARIES:
BIN_ROOT="$ES_SCRATCH/APPS/NEMO_V40_STELLA/cfgs"
TRAILER_BIN="EXP00/nemo"
INTEL_DOUBLE_BIN="$BIN_ROOT/ORCA-INTEL-IMPI/${TRAILER_BIN}"
INTEL_MIXED_BIN="$BIN_ROOT/ORCA-INTEL-IMPI_MIXED/${TRAILER_BIN}"
INTEL_ENV="env/mn5-gpp-intel"

INTEL_OMPI_DOUBLE_BIN="$BIN_ROOT/ORCA-INTEL-OPENMPI/${TRAILER_BIN}"
INTEL_OMPI_MIXED_BIN="$BIN_ROOT/ORCA-INTEL-OPENMPI_MIXED/${TRAILER_BIN}"
INTEL_OMPI_ENV="env/mn5-gpp-intel-openmpi"

GCC_DOUBLE_BIN="$BIN_ROOT/ORCA-GCC-OPENMPI/$TRAILER_BIN"
GCC_MIXED_BIN="$BIN_ROOT/ORCA-GCC-OPENMPI_MIXED/$TRAILER_BIN"
GCC_ENV="env/mn5-gpp-gcc-openmpi"

#SIMULATION & RUNDIR:
TS=1448
EXP_DATE=$(date +"%Y-%m-%d@%H-%M-%S")
RUNDIR_BASE="$ES_SCRATCH/RUNDIR-NEMO-VARIABILITY"

RUNDIR_DOUBLE="$RUNDIR_BASE/eORCA1-DOUBLE/${TS}_TS/"
for NODE in 1 2 4 8
do
    for MPI_TASKS in 112
    do
        for MIRROR in {1..5}
        do
            RUNDIR_NAME=${NODE}-nodes/${MPI_TASKS}-tasks/$EXP_DATE/mirror-${MIRROR}

            INTEL_RUNDIR="${RUNDIR_DOUBLE}/INTEL-IMPI/${RUNDIR_NAME}"
            BIN=$INTEL_DOUBLE_BIN
            ENV=$INTEL_ENV

            ./run_nemo.sh --steps $TS --nodes $NODE --MPI $MPI_TASKS --OpenMP 1 \
            --ref-rundir $EORCA_INPUTS --account ehpc01 --queue gp_ehpc --force\
            --bin $BIN  --env $ENV  --rundir $INTEL_RUNDIR
            
            INTEL_OMPI_RUNDIR="${RUNDIR_DOUBLE}/INTEL-OMPI/${RUNDIR_NAME}"
            BIN=$INTEL_OMPI_DOUBLE_BIN
            ENV=$INTEL_OMPI_ENV

            ./run_nemo.sh --steps $TS --nodes $NODE --MPI $MPI_TASKS --OpenMP 1 \
            --ref-rundir $EORCA_INPUTS --account ehpc01 --queue gp_ehpc --force\
            --bin $BIN  --env $ENV  --rundir $INTEL_OMPI_RUNDIR

            GCC_RUNDIR="${RUNDIR_DOUBLE}/GCC-OPENMPI/${RUNDIR_NAME}"

        done
    done
done

RUNDIR_MIXED="$RUNDIR_BASE/eORCA1-MIXED/${TS}_TS/"
for NODE in 1 2 4 8
do
    for MPI_TASKS in 112
    do
        for MIRROR in {1..5}
        do
            RUNDIR_NAME=${NODE}-nodes/${MPI_TASKS}-tasks/$EXP_DATE/mirror-${MIRROR}

            INTEL_RUNDIR="${RUNDIR_MIXED}/INTEL-IMPI/${RUNDIR_NAME}"
            BIN=$INTEL_MIXED_BIN
            ENV=$INTEL_ENV

            ./run_nemo.sh --steps $TS --nodes $NODE --MPI $MPI_TASKS --OpenMP 1 \
            --ref-rundir $EORCA_INPUTS --account ehpc01 --queue gp_ehpc --force \
            --bin $BIN  --env $ENV  --rundir $INTEL_RUNDIR 

            INTEL_OMPI_RUNDIR="${RUNDIR_MIXED}/INTEL-OMPI/${RUNDIR_NAME}"
            BIN=$INTEL_OMPI_MIXED_BIN
            ENV=$INTEL_OMPI_ENV

            ./run_nemo.sh --steps $TS --nodes $NODE --MPI $MPI_TASKS --OpenMP 1 \
            --ref-rundir $EORCA_INPUTS --account ehpc01 --queue gp_ehpc --force \
            --bin $BIN  --env $ENV  --rundir $INTEL_OMPI_RUNDIR

            GCC_RUNDIR="${RUNDIR_BASE}/GCC-OPENMPI/${RUNDIR_NAME}"
        done
    done
done

