#!/bin/bash

# Author: Victor Correal (victor.correal@bsc.es)
# Date  : 28/06/2024


# IMPORTS:
UTILS_DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)"
source ${UTILS_DIR}/../../bash_utils/helpers.sh
source ${UTILS_DIR}/run_nemo_utils.sh

# SIM VARIABLES:
BIN_FILE=
ENV_FILE=
RUNDIR=
REF_RUNDIR=
STEPS=
FORCE_RUN=false
MONITOR=false
USE_EXTRAE=false
PROFILE=false
PROFILER=

# SLURM VARIABLES:
ACCOUNT=DEFAULT
NODES=DEFAULT
QUEUE=DEFAULT
TIME_LIMIT=DEFAULT
MPI_PER_NODE=DEFAULT
OMP_PER_TASK=DEFAULT
SLURM_WAIT=false
SLURM_CONTIGUOUS=false
SLURM_ARGS=""

# PARSE ARGS:
parse_args "$@"

# CHECK ENV, BIN, SLURM & INPUTS:
check_required_args
check_slurm_options
print_options
check_dirs

# USER CHECK(Y/N):
check_user

# CREATE & FILL RUNDIR:
REAL_ENV="$(readlink -f "$ENV_FILE")"
REAL_BIN="$(readlink -f "$BIN_FILE")"

mkdir -p $RUNDIR
cp -P $REF_RUNDIR/* $RUNDIR
cp $REAL_BIN $RUNDIR/nemo
cp $REAL_ENV $RUNDIR/env.sh
cp ${UTILS_DIR}/../../running/nemo-standalone/run_nemo_directory.slurm ${RUNDIR}/run_nemo.slurm

# RUN WITH SLURM:
cd $RUNDIR
sed -i 's/nn_stock=.*/nn_stock=-1/' "namelist_cfg"
sed -i 's/[[:space:]]*nn_stock[[:space:]]*=[[:space:]]*.*/nn_stock=-1/' "namelist_cfg"

sed -i "s/nn_itend[ \t]*=.*/nn_itend=$STEPS/" namelist_cfg

if [ $USE_EXTRAE = true ]; then
    info "USING EXTRAE!"
    PROFILER="extrae"
    cp ${UTILS_DIR}/extrae-env/* .
    ./create_functions_list.sh nemo functions_list_small.txt
    echo "module load extrae papi" >> env.sh
fi

if [ $PROFILE = true ]; then
    info "PROFILING: ON"
    PROFILER=custom
fi

JOB_ID=$(sbatch $SLURM_ARGS --parsable run_nemo.slurm $PROFILER)


# MONITOR IF REQUESTED:
if $MONITOR; then
    OUTPUT_LOG="slurm-$JOB_ID.out"
    info "MONITOR ENABLE FOR THIS JOB! WAITING FOR THE OUTPUT LOG..."
    while [ ! -f "$OUTPUT_LOG" ]; do
        sleep 1
    done

    info "FOUND OUTPUT LOG! => $PWD/$OUTPUT_LOG"
    #less +F $OUTPUT_LOG

else
    info "SUBMIT JOB $JOB_ID"
    info "##############################################"
fi





